@@ -6,22 +6,23 @@ from math import gcd
 from .factor import factorint
 from .intfuncs import prime_power
 
+
 class Zmod:
     """
     Ring of intergers modulo `n`.
 
     Example:
-    
+
     To define a finite Galois field modulo the prime 5 use
-    >>> gf=Zmod(5)
-    
+    >>> Z_5=Zmod(5)
+
     To declare 3 as an element of our Galois filed use
-    >>> gf(3)
-    3 (mod 5)
+    >>> Z_5(3)
+    3
 
     The usual arithmetic operations are supported.
-    >>> gf(2) + gf(3)
-    0 (mod 5)
+    >>> Z_5(2) + Z_5(3)
+    0
     """
 
     def __init__(self, n: int, short: bool = True):
@@ -30,15 +31,19 @@ class Zmod:
         self.n = n
         self.short = short
         self.group_order = 0
-        self.factors = {} # factoring of the group order
+        self.factors = {}  # factoring of the group order
 
-    def __call__(self, x: int|list|tuple):
+    def __call__(self, x: int | list | tuple):
         if isinstance(x, list):
             return [ZmodPoint(xx, self) for xx in x]
-        elif isinstance(x, tuple):
+        if isinstance(x, tuple):
             return (ZmodPoint(xx, self) for xx in x)
         return ZmodPoint(x, self)
 
+    def __iter__(self):
+        for x in range(self.n):
+            yield ZmodPoint(x, self)
+
     def __eq__(self, other):
         if isinstance(other, self.__class__):
             return self.n == other.n
@@ -53,12 +58,14 @@ class Zmod:
             return self.group_order
         # We compute euler_phi(n) and its factorization in one pass
         for p, k in factorint(self.n).items():  # first factorize n
-            for pm, km in factorint(p - 1).items():  # factor p-1 and add the factors
+            # factor p-1 and add the factors
+            for pm, km in factorint(p - 1).items():
                 if pm in self.factors:
                     self.factors[pm] += km
                 else:
                     self.factors[pm] = km
-            if k > 1:  # if the multiplicity of of p is >1, then we need to add p**(k-1)
+            # if the multiplicity of of p is >1, then we need to add p**(k-1)
+            if k > 1:
                 if p in self.factors:
                     self.factors[p] += k - 1
                 else:
@@ -81,30 +88,33 @@ class Zmod:
             return True
         return False
 
-    def generator(self, all = False) -> int|None:
+    def generator(self) -> int | None:
         """Return a generator of the group Z_n^*."""
         if not self.is_cyclic():
-            if all:
-                return []
             return None
         for a in range(2, self.n):
             if gcd(a, self.n) > 1:
                 continue
             a = self(a)
             if a.is_generator():
-                if all:
-                    self.order()
-                    return list( a**j for j in range(1, self.group_order) if gcd(j,self.group_order) == 1 )
                 return a
 
-    def star(self) -> int:
-        """Return a list of all elements of the group Z_n^*."""
-        elements = [ self(1) ]
+    def generators(self) -> list | None:
+        """Return a generator for all generators of the group Z_n^*."""
+        a = self.generator()
+        if a is not None:
+            self.order()
+            for j in range(1, self.group_order):
+                if gcd(j, self.group_order) == 1:
+                    yield a**j
+
+    def star(self) -> list:
+        """Return a generator for all elements of the group Z_n^*."""
+        yield self(1)
         for a in range(2, self.n):
-            if gcd(a, self.n) > 1:
-                continue
-            elements.append(self(a))
-        return elements
+            if gcd(a, self.n) == 1:
+                yield self(a)
+
 
 class ZmodPoint:
     "Represents a point in the ring Zmod."
