@@ -4,26 +4,21 @@ Polynomials
 
 from numbers import Number
 
-display_reversed = True
-
-def poly_style_reversed(value: bool = True) -> None:
-    "Change the order of the coefficients when displaying polynomials."
-    global display_reversed
-    display_reversed = value
-
 
 class Poly:
     """
     Represents a polynomial as a list of coefficients.
-    
+
     Example:
-    
+
     To define a polynomial as a list of coefficients use
     >>> Poly([1, 2, 3])
     3 x^2 + 2 x + 1
     """
 
-    def __init__(self, coeff: list, ring = None, modulus: list = None):
+    print_reversed = True  # print the terms in reversed order
+
+    def __init__(self, coeff: list, ring=None, modulus: list = None):
         self.coeff = list(coeff)
         for i in range(len(self.coeff) - 1, 0, -1):
             if self.coeff[i]:
@@ -61,7 +56,7 @@ class Poly:
         plus = ""
         tmp = ""
         coef_range = range(len(self.coeff))
-        if display_reversed:
+        if self.__class__.print_reversed:
             coef_range = reversed(coef_range)
         for i in coef_range:
             s = self.coeff[i]
@@ -167,22 +162,17 @@ class Poly:
     def __mul__(self, other: "Poly") -> "Poly":
         if not isinstance(other, self.__class__):
             if self._check_type(other):
-                return Poly([other * s for s in self.coeff], modulus = self.modulus)
+                return Poly([other * s for s in self.coeff], modulus=self.modulus)
             return NotImplemented
         zero = 0 * self.coeff[0]
         ls, lo = len(self.coeff), len(other.coeff)
         coeff = [None] * (ls + lo - 1)
         for k in range(ls + lo - 1):
-            coeff[k] = sum(
-                [
-                    self.coeff[j] * other.coeff[k - j]
-                    for j in range(max(0, k - lo + 1), min(ls, k + 1))
-                ]
-            , start = zero)
+            coeff[k] = sum((self.coeff[j] * other.coeff[k - j] for j in range(max(0, k - lo + 1), min(ls, k + 1))), start=zero)
         modulus = self.modulus
         if not modulus and other.modulus:
             modulus = other.modulus
-        return self.__class__(coeff, modulus = modulus)
+        return self.__class__(coeff, modulus=modulus)
 
     def __rmul__(self, other) -> "Poly":
         return self * other
@@ -224,11 +214,11 @@ class Poly:
 
     def max(self) -> int:
         "Maximum of the absolute value of all coefficients."
-        return max([abs(c) for c in self.coeff])
+        return max(abs(c) for c in self.coeff)
 
     def sum(self) -> int:
         "Sum of the absolute value of all coefficients."
-        return sum([abs(c) for c in self.coeff])
+        return sum(abs(c) for c in self.coeff)
 
     def __floordiv__(self, other: "Poly") -> "Poly":
         return self.divmod(other)[0]
@@ -240,7 +230,7 @@ class Poly:
         "Polynom division with remainder."
         zero, one, ring = self._guess_ring()
         if isinstance(other, list):
-            other = self.__class__(other , ring = ring)
+            other = self.__class__(other, ring=ring)
         elif not isinstance(other, self.__class__):
             raise NotImplementedError(f"Cannot divide {self} and {other}.")
         if not other:
@@ -258,7 +248,7 @@ class Poly:
             oth = other.coeff
             rem = [c * one for c in self.coeff] # "* 1" is here to make sure we get a copy
         for i in range(sd - od + 1):
-            tmp = rem[sd - i] * one # "* 1" is here to make sure we get a copy
+            tmp = rem[sd - i] * one  # "* 1" is here to make sure we get a copy
             div[sd - od - i] = tmp
             for j in range(od + 1):
                 rem[sd - i - j] -= tmp * oth[od - j]
@@ -270,7 +260,7 @@ class Poly:
         "Reduce with respect to a given polynomial."
         one, ring = self._guess_ring()[1:]
         if isinstance(other, list):
-            other = self.__class__(other , ring = ring)
+            other = self.__class__(other, ring=ring)
         elif not isinstance(other, self.__class__):
             raise NotImplementedError(f"Cannot divide {self} and {other}.")
         if not other:
@@ -299,7 +289,7 @@ class Poly:
             other = self.modulus
         zero, one, ring = self._guess_ring()
         if isinstance(other, list):
-            other = self.__class__(other , ring = ring)
+            other = self.__class__(other, ring=ring)
         elif not isinstance(other, self.__class__):
             raise NotImplementedError(f"Cannot invert {self} modulo {other}.")
         if not other:
@@ -316,3 +306,13 @@ class Poly:
         for i in range(len(y0)):
             y0.coeff[i] *= tmp
         return y0
+
+    def gcd(self, other: "Poly") -> "Poly":
+        "Greates common divisor with a given polynomial."
+        if not isinstance(other, self.__class__):
+            raise NotImplementedError(f"Cannot compute gcd: {other} must be a polynomial.")
+        r0, r1 = other, self
+        while r1:
+            q, r = r0.divmod(r1)
+            r0, r1 = r1, r
+        return r0
